TimedMap

Struct TimedMap 

pub struct TimedMap<K, V, TS = Instant> { /* private fields */ }
Provides a hash map with expiring key-value pairs.

Basic Example

use timedmap::TimedMap;
use std::time::Duration;

let tm = TimedMap::new();
tm.insert("foo", "bar", Duration::from_secs(10));
assert_eq!(tm.get(&"foo"), Some("bar"));

Implementations

Source

impl<K, V> TimedMap<K, V>

pub fn new() -> Self

Create a new instance of TimedMap with the default TimeSource implementation Instant.

Source

impl<K, V, TS> TimedMap<K, V, TS>

pub fn new_with_timesource() -> Self

Create a new instance of TimedMap with a custom TimeSource implementation.

Source

impl<K, V, TS> TimedMap<K, V, TS>
where K: Eq + PartialEq + Hash + Clone, V: Clone, TS: TimeSource,

pub fn insert(&self, key: K, value: V, lifetime: Duration)

Add a new key-value pair to the map with the given lifetime.

When the lifetime has passed, the key-value pair will be no more accessible.

Example
use timedmap::TimedMap;
use std::time::Duration;

let tm = TimedMap::new();
tm.insert("foo", "bar", Duration::from_millis(10));
assert_eq!(tm.get(&"foo"), Some("bar"));

std::thread::sleep(Duration::from_millis(20));
assert_eq!(tm.get(&"foo"), None);
pub fn get(&self, key: &K) -> Option<V>

Returns a copy of the value corresponding to the given key.

None is returned when the values lifetime has been passed.

Behavior

If the key-value pair has expired and not been cleaned up before, it will be removed from the map on next retrival try.

pub fn contains(&self, key: &K) -> bool

Returns true when the map contains a non-expired value for the given key.

Behavior

Because this method is basically a shorthand for get(key).is_some(), it behaves the same on retrival of expired pairs.

pub fn remove<Q>(&self, key: &Q) -> Option<V>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Removes the given key-value pair from the map and returns the value if it was previously in the map and is not expired.

pub fn refresh(&self, key: &K, new_lifetime: Duration) -> bool

Sets the lifetime of the value coresponding to the given key to the new lifetime from now.

Returns true if a non-expired value exists for the given key.

pub fn extend(&self, key: &K, added_lifetime: Duration) -> bool

Extends the lifetime of the value coresponding to the given key to the new lifetime from now.

Returns true if a non-expired value exists for the given key.

pub fn len(&self) -> usize

Returns the number of key-value pairs in the map which have not been expired.

pub fn is_empty(&self) -> bool

Returns true when the map does not contain any non-expired key-value pair.

pub fn clear(&self)

Clears the map, removing all key-value pairs.

pub fn snapshot<B: FromIterator<(K, V)>>(&self) -> B

Create a snapshot of the current state of the maps key-value entries.

It does only contain all non-expired key-value pairs.

pub fn get_value<Q>(&self, key: &Q) -> Option<Value<V, TS>>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Retrieves the raw Value wrapper by the given key if the key-value pair has not been expired yet.

If the given key-value pair is expired and not cleaned up yet, it will be removed from the map automatically.

pub fn get_value_unchecked<Q>(&self, key: &Q) -> Option<Value<V, TS>>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Retrieves the raw Value wrapper by the given key without checking expiry.